@@ -1,3 +1,4 @@
+"""Tests conftest file."""
 import os
 import sys
 
@@ -16,6 +17,7 @@ full_path = os.path.join(package_path(package), filename)
 @pytest.fixture(scope='function',
                 params=['tests:config', 'tests:config/config.yaml', full_path])
 def base_config(request):
+    """Basic config parametrized for different configuration location."""
     return factories.pyramid_config({
         'yaml.location': request.param,
         'pyramid.includes': ['tzf.pyramid_yml']
@@ -25,6 +27,7 @@ def base_config(request):
 @pytest.fixture(scope='function',
                 params=['tests:config', 'tests:config/config.yaml', full_path])
 def prod_config(request):
+    """Basic with env set parametrized for different configuration location."""
     return factories.pyramid_config({
         'env': 'prod',
         'yaml.location': request.param,
@@ -32,8 +35,13 @@ def prod_config(request):
     })(request)
 
 
-multifolder_config = factories.pyramid_config({
-    'env': 'prod',
-    'yaml.location': ['tests:config', 'tests:config2'],
-    'pyramid.includes': ['tzf.pyramid_yml']
-})
+@pytest.fixture(
+    scope='function',
+    params=[['tests:config', 'tests:config2'], 'tests:config, tests:config2'])
+def multifolder_config(request):
+    """Test with two ways of setting many locations for config."""
+    return factories.pyramid_config({
+        'env': 'prod',
+        'yaml.location': request.param,
+        'pyramid.includes': ['tzf.pyramid_yml']
+    })(request)
