@@ -1,12 +1,11 @@
-# -*- coding: utf-8 -*-
+"""pconfig elements tests."""
 
 import pytest
 from tzf.pyramid_yml import scripts
 
 
 def test_simplevalue():
-    '''tests for simple value
-    '''
+    """Test for simple value."""
     line = scripts.printer(1)
     # value passed should be represented by type in round parenthesis
     assert line == '1 (int)'
@@ -20,7 +19,7 @@ def test_simplevalue():
     ({'key': {'key2': 'value'}}, 2),  # composite key
 ))
 def test_printer_list(configvalue, countlines):
-    '''printer: key:[value:value]'''
+    """Test printer: key:[value:value]."""
     lines = scripts.printer(configvalue).split('\n')
     # should be three lines. one for key, and two for list
     assert len(lines) == countlines
@@ -35,6 +34,6 @@ conf_slicing = {'key': 'value', 'key2': {'key3': 'value'}}
     (conf_slicing, 'key2.key3', conf_slicing['key2']['key3']),
 ))
 def test_slice(config, slice_key, sliced):
-    '''test no slice pass for config'''
+    """Test no slice pass for config."""
     # configuration should be the same
     assert sliced == scripts._slice_config(config, slice_key)
