@@ -1,10 +1,9 @@
-# -*- coding: utf-8 -*-
-
-# Copyright (c) 2013 by tzf.pyramid_yml authors and contributors
+# Copyright (c) 2013 - 2014 by tzf.pyramid_yml authors and contributors
 #   <see AUTHORS file>
 #
 # This module is part of tzf.pyramid_yml and is released under
 # the MIT License (MIT): http://opensource.org/licenses/MIT
+"""First level of namespace package."""
 
 # See http://peak.telecommunity.com/DevCenter/setuptools#namespace-packages
 try:
