@@ -1,9 +1,9 @@
-# -*- coding: utf-8 -*-
-
-# Copyright (c) 2013 by tzf.pyramid_yml authors and contributors <see AUTHORS file>
+# Copyright (c) 2013 - 2014 by tzf.pyramid_yml authors and contributors
+# <see AUTHORS file>
 #
 # This module is part of tzf.pyramid_yml and is released under
 # the MIT License (MIT): http://opensource.org/licenses/MIT
+"""pyramid_yml main functionality."""
 
 import os
 import logging
@@ -12,19 +12,18 @@ from pyramid.asset import resolve_asset_spec
 from pyramid.path import package_path
 from pymlconf import ConfigManager
 
-__version__ = '1.0.0'
+__version__ = '1.0.1'
 
 
 logger = logging.getLogger(__name__)
 
 
-def includeme(configurator, routing_package=None):
-    '''
-        Adds rotues defined in config into pyramid app
-
-        :param pyramid.config.Configurator configurator: pyramid's app configurator
-    '''
+def includeme(configurator):
+    """
+    Add yaml configuration utilities.
 
+    :param pyramid.config.Configurator configurator: pyramid's app configurator
+    """
     settings = configurator.registry.settings
 
     # lets default it to running path
@@ -51,25 +50,27 @@ def includeme(configurator, routing_package=None):
 
     # let's calla a convenience request method
     configurator.add_request_method(
-        lambda request: request.registry['config'], name='config', property=True)
+        lambda request: request.registry['config'],
+        name='config', property=True
+    )
 
 
-def config_defaults(configurator, config_locations, files=['config.yaml', 'config.yml']):
-    '''
-        Reads and extends/creates configuration from yaml source.
+def config_defaults(
+        configurator, config_locations, files=['config.yaml', 'config.yml']):
+    """
+    Read and extends/creates configuration from yaml source.
 
-        .. note::
-            If exists, this method extends config with defaults,
-            so it will not override existing values, merely add those,
-            that were not defined already!
-
-        :param pyramid.config.Configurator configurator: pyramid's app configurator
-        :param list config_locations: list of yaml file locations
-        :param list files: list of files to include from location
-    '''
+    .. note::
+        If exists, this method extends config with defaults,
+        so it will not override existing values, merely add those,
+        that were not defined already!
 
+    :param pyramid.config.Configurator configurator: pyramid's app configurator
+    :param list config_locations: list of yaml file locations
+    :param list files: list of files to include from location
+    """
     if not isinstance(config_locations, (list, tuple)):
-        config_locations = (config_locations,)
+        config_locations = config_locations.split(',')
 
     env = configurator.registry.settings.get('env', 'dev')
 
@@ -81,14 +82,17 @@ def config_defaults(configurator, config_locations, files=['config.yaml', 'confi
             path, current_files = os.path.split(path)
             current_files = [current_files]
 
-        for config_path in [os.path.join(path, f) for f in _env_filenames(current_files, env)]:
+        for config_path in [
+            os.path.join(path, f) for f in _env_filenames(current_files, env)
+        ]:
             if os.path.isfile(config_path):
                 file_paths.append(config_path)
 
     config = ConfigManager(files=file_paths)
 
-    # we could use this method both for creating and extending. Hence the checks to not override
-    if not 'config' in configurator.registry:
+    # we could use this method both for creating and extending.
+    # Hence the checks to not override
+    if 'config' not in configurator.registry:
         configurator.registry['config'] = config
     else:
         config.merge(configurator.registry['config'])
@@ -96,18 +100,18 @@ def config_defaults(configurator, config_locations, files=['config.yaml', 'confi
 
 
 def _translate_config_path(location):
-    '''
-    Translates location into fullpath according asset specification.
+    """
+    Translate location into fullpath according asset specification.
+
     Might be package:path for package related paths, or simply path
 
     :param str location: resource location
     :returns: fullpath
 
     :rtype: str
-    '''
-
+    """
     # getting spec path
-    package_name, filename = resolve_asset_spec(location)
+    package_name, filename = resolve_asset_spec(location.strip())
     if not package_name:
         path = filename
     else:
@@ -118,15 +122,15 @@ def _translate_config_path(location):
 
 
 def _env_filenames(filenames, env):
-    '''
-    Extends filenames with ennv indication of environments
+    """
+    Extend filenames with ennv indication of environments.
 
     :param list filenames: list of strings indicating filenames
     :param str env: environment indicator
 
     :returns: list of filenames extended with environment version
     :rtype: list
-    '''
+    """
     env_filenames = []
     for filename in filenames:
         filename_parts = filename.split('.')
@@ -137,31 +141,46 @@ def _env_filenames(filenames, env):
 
 
 def _extend_settings(settings, configurator_config, prefix=None):
-    '''
-        Extends settings dictionary with yml'settings defined in configurator: key
+    """
+    Extend settings dictionary with content of yaml's  configurator key.
 
-        :param dict settings: settings dictionary
-        :param dict configurator_config: yml defined settings
-        :param str prefix: prefix for settings dict key
-    '''
+    .. note::
 
+        This methods changes multilayered subkeys defined
+        within **configurator** into dotted keys in settings dictionary:
+
+        .. code-block:: yaml
+
+            configurator:
+                sqlalchemy:
+                    url: mysql://user:password@host/dbname
+
+        will result in **sqlalchemy.url**: mysql://user:password@host/dbname
+        key value in settings dictionary.
+
+    :param dict settings: settings dictionary
+    :param dict configurator_config: yml defined settings
+    :param str prefix: prefix for settings dict key
+    """
     for key in configurator_config:
         settings_key = '.'.join([prefix, key]) if prefix else key
 
-        if hasattr(configurator_config[key], 'keys') and hasattr(configurator_config[key], '__getitem__'):
-            _extend_settings(settings, configurator_config[key], prefix=settings_key)
+        if hasattr(configurator_config[key], 'keys') and\
+                hasattr(configurator_config[key], '__getitem__'):
+            _extend_settings(
+                settings, configurator_config[key], prefix=settings_key
+            )
         else:
             settings[settings_key] = configurator_config[key]
 
 
 def _run_includemes(configurator, includemes):
-    '''
-        Runs configurator.include() for packages defined in include key in yaml configuration
-
-        :param pyramid.config.Configurator configurator: pyramid's app configurator
-        :param dict includemes: include, a list of includes or dictionary
-    '''
+    """
+    Automatically include packages defined in **include** configuration key.
 
+    :param pyramid.config.Configurator configurator: pyramid's app configurator
+    :param dict includemes: include, a list of includes or dictionary
+    """
     for include in includemes:
         if includemes[include]:
             try:
