@@ -1,9 +1,9 @@
-# -*- coding: utf-8 -*-
-
-# Copyright (c) 2013 by tzf.pyramid_yml authors and contributors <see AUTHORS file>
+# Copyright (c) 2013 - 2014 by tzf.pyramid_yml authors and contributors
+# <see AUTHORS file>
 #
 # This module is part of tzf.pyramid_yml and is released under
 # the MIT License (MIT): http://opensource.org/licenses/MIT
+"""Module behind pconfig commandline entrypoint."""
 
 import optparse
 import sys
@@ -15,7 +15,7 @@ _indent = '  '
 
 
 def print_config():  # pragma: no cover
-
+    """Print config entry function."""
     description = """\
         Print the deployment settings for a Pyramid application.  Example:
         'psettings deployment.ini'
@@ -31,7 +31,8 @@ def print_config():  # pragma: no cover
         metavar='PREFIX',
         type='string',
         action='store',
-        help=("Tells script to print only specified config tree provided by dotted name")
+        help=("Tells script to print only specified"
+              " config tree provided by dotted name")
     )
 
     options, args = parser.parse_args(sys.argv[1:])
@@ -46,21 +47,24 @@ def print_config():  # pragma: no cover
     try:
         print(printer(_slice_config(config, options.key)))
     except KeyError:
-        print('Sorry, but the key path {0}, does not exists in Your config!'.format(options.key))
+        print(
+            'Sorry, but the key path {0}, does not exists in Your config!'
+            .format(options.key)
+        )
     finally:
         closer()
 
 
 def printer(data, depth=0):
-    '''
-        Methods prepares config tree for printing
+    """
+    Prepare data for printing.
 
-        :param data: a data value that will be processed by method
-        :param int depth: recurrency indicator, to maintain proper ident
+    :param data: a data value that will be processed by method
+    :param int depth: recurrency indicator, to maintain proper indent
 
-        :returns: string with formatted config
-        :rtype: str
-    '''
+    :returns: string with formatted config
+    :rtype: str
+    """
     ident = _indent * depth
     config_string = '' if not depth else ':\n'
     if isinstance(data, dict):
@@ -77,22 +81,23 @@ def printer(data, depth=0):
         for el in data:
             config_string += '{0} - {1}\n'.format(ident, el)
     else:
-        config_string = '{0}{1} ({2})'.format(ident, data, data.__class__.__name__)
+        config_string = '{0}{1} ({2})'.format(
+            ident, data, data.__class__.__name__
+        )
 
     return config_string.rstrip('\n')
 
 
 def _slice_config(config, key):
-    '''
-    slices config for printing as defined in key
+    """
+    slice config for printing as defined in key.
 
     :param ConfigManager config: configuration dictionary
     :param str key: dotted key, by which config should be sliced for printing
 
     :returns: sliced config
     :rtype: dict
-    '''
-
+    """
     if key:
         keys = key.split('.')
         for k in keys:
